# cyclone ai-platform python framework

## Dependencies
* [flask-restx](https://pypi.org/project/flask-restx/0.1.1/)
* [flask-cors](https://pypi.org/project/Flask-Cors/)

## Installation

```shell script
pip install -U cyclonefw
```

## Demo

```python

#!/usr/bin/env python3

from cyclonefw import MAXApp

app = MAXApp()
app.run()


```
